@@ -45,7 +45,7 @@
 	}
 ### map structure or URL used to download the tile.
  }, ex = function(){
-  if (0) {
+if (interactive()) {
  	CologneMap <- GetMap.OSM(lonR= c(6.89, 7.09), latR = c(50.87, 51), scale = 150000, 
                             destfile = "Cologne.png");
 	PlotOnStaticMap(CologneMap, mar=rep(4,4), NEWMAP = FALSE, TrueProj = FALSE, axes= TRUE);
@@ -54,7 +54,7 @@
                              scale = 12500, destfile = "Princeton.png");
 	png("PrincetonWithAxes.png", 1004, 732)
       PlotOnStaticMap(PrincetonMap, axes = TRUE, mar = rep(4,4));
-      dev.off()
+    dev.off()
  }
 })
 
