@@ -2,15 +2,23 @@
 ###This function plots/overlays polygons on a map. Typically, the polygons originate from a shapefile.
 (
   MyMap, ##<< map image returned from e.g. \code{GetMap()}
-  polys, ##<<  polygons to overlay
+  polys, ##<<  polygons to overlay; these can be either of class \link[PBSmapping]{PolySet} from the package PBSmapping
+### or of class \link[sp]{SpatialPolygons} from the package sp
   col, ##<< (optional) vector of colors, one for each polygon
   border = NULL, ##<< the color to draw the border. The default, NULL, means to use \link{par}("fg"). Use border = NA to omit borders, see \link{polygon}
   lwd = .25, ##<< line width, see \link{par}
   verbose = 0, ##<< level of verbosity 
   add=TRUE, ##<< start a new plot or add to an existing 
+  textInPolys = NULL, ##<< text to be displayed inside polygons.
   ... ##<< further arguments passed to \code{PlotOnStaticMap}
 ){
   ##seealso<< \link{PlotOnStaticMap} \link{mypolygon}
+  ##details<< 
+  #print(str(polys))
+  stopifnot(class(polys)[1] == "SpatialPolygons" | class(polys)[1] == "PolySet" | class(polys)[1] == "data.frame" | class(polys)[1] == "matrix")
+  if (class(polys)[1] == "SpatialPolygons")
+    polys = SpatialToPBS(polys)$xy
+  
   Rcoords <- LatLon2XY.centered(MyMap,lat= polys[,"Y"],lon= polys[,"X"]);
   polys.XY <- as.data.frame(polys);
   polys.XY[,"X"] <- Rcoords$newX;
@@ -23,11 +31,15 @@
   polys.XY[,"PIDSID"] <- apply(polys.XY[,c("PID","SID")],1,paste,collapse=":")
   if (!add) tmp <- PlotOnStaticMap(MyMap, verbose=0, ...)
   if (verbose>1) browser()
-
+  #browser()
+  if (!is.null(textInPolys)) Centers = calcCentroid(polys.XY)
 if (require(PBSmapping) & all(c("PID","X","Y","POS") %in% colnames(polys.XY)) ) {
 	attr(polys.XY, "projection") <- NULL;
 	usr <- par('usr')
 	addPolys(polys.XY,col=col, border = border, lwd = lwd, xlim =usr[1:2], ylim = usr[3:4],  ...)
+	if (!is.null(textInPolys)) {
+	  text(Centers[,"X"],Centers[,"Y"],textInPolys,cex=0.75, col = "blue")
+	}
 } else {
   if (!missing(col)) {
   	polys.XY[,"col"] <- col;
@@ -36,25 +48,29 @@ if (require(PBSmapping) & all(c("PID","X","Y","POS") %in% colnames(polys.XY)) )
   	if (length(SIDtable)==length(col))  polys.XY[,"col"] <- rep(col, SIDtable);
   	if (length(PIDtable)==length(col))  polys.XY[,"col"] <- rep(col, PIDtable);
   }
-  
+ 
   if ( !( "col" %in% colnames(polys.XY)) )
      polys.XY[,"col"] <- rgb(.1,.1,.1,.05);
     #polys.XY[polys.XY[,"PID"] == 292,"col"] <- rgb(1,0,0,.75)
   #tmp <- by(polys.XY[,c("X","Y","col")], polys.XY[,"PID"], mypolygon, lwd = lwd, border = border);
   #if (0){
   	pids = unique(polys.XY[,"PIDSID"])
+    
   	for (i in pids){
   	  jj = 	polys.XY[,"PIDSID"] == i;
   	  xx= polys.XY[jj,];
   	  if ( ( "POS" %in% colnames(xx)) ) xx <- xx[order(xx[,"POS"]),]
   	  polygon( xx[, c("X","Y")], col=xx[,"col"]);
+  	  if (!is.null(textInPolys)) {
+  	    text(Centers[i,"X"],Centers[i,"Y"],textInPolys[i], col = "blue")
+  	  }
   	  #readLines(n=1)
   	}
   #}
   }
 }, ex = function(){
-  if (0){
-  require(PBSmapping);
+if (interactive()){
+  #require(PBSmapping);
   shpFile <- paste(system.file(package = "RgoogleMaps"), "/shapes/bg11_d00.shp", sep = "")
   #shpFile <- system.file('bg11_d00.shp', package = "RgoogleMaps");
   
